==> lapras-0.0.5.tar.gz: lapras-0.0.5/lapras/ModelConfig.py <==
# coding:utf-8

# 离散桶
bucketnum = 0
# 树深度
treeDepth = 3
# 最小子数目
minLeaf = 100

# 模型基准分
A = 363.7244
B = 57.7078
eps = 1e-8




# 房天下配置
bin_params_dict_fang = {
    'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'position_title_level':[1.5, 2.5, 3.5],
    # 'sex_male':[ 0.5], #数据异常
    # 'age':[ 25.5, 36.5], #数据异常
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    'work_city_level':[3.5],
    # 'census_type_level':[1.5, 2.5],#数据异常
    'list_ct':[-49.0, 1.5],
    # 'list_total_loan':[-49.5],#数据异常
    'house_ct':[-49.0],
    'marriage_level':[1.5],
    'rent_avg_amt':[1325.0],
    'rent_period':[-49.5],
}



#链家德佑KA的模型参数
bin_params_dict_lianjia = {
    'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'ke_quality': [ 174.5, 312.5, 329.5, 361.5, 376.5, 403.5],
    # 'byj_loan_amount': [ 800, 1450.0, 29750.0],
    'byj_app_amount': [ 1450.0, 29750.0],
    'byj_loan_periods': [ 6, 9.0],
    # 'byj_loan_rate': [ -49.45],
    'income': [ 248554.5, 552007.5, 1133606.5, 1347582.0],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'agent_del_rate': [ -49.388, 0.384],
    # 'shop_del_rate': [ -49.048, 0.982],
    # 'agent_cnt': [ -6.5, 190.5],
    # 'agent_del_cnt': [ -39.5, 77.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'shop_del_cnt': [ -47.5],
    # 'shop_cnt':[ -47.5],
    'shop_annual_income':[ 3389728.5, 11353908.0, 18822910.0],
    # 'position_title_level':[1.5, 2.5, 3.5],
    'sex_male':[ 0.5],
    'degree_level':[-48.0, 2,5.0],
    'census_city_level':[-49.0, 2.5, 4.5],
    'age':[ 25.5, 36.5],
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    'work_city_level':[3.5],
    'census_type_level':[1.5, 2.5],
    # 'list_ct':[-49.0, 1.5],
    'list_total_loan':[-49.5],
    # 'list_total_mortgage':[-49.5],
    'house_ct':[-49.0],
    'marriage_level':[1.5],
    'college_level':[-49.0,3.5],
    'rent_avg_amt':[1325.0],
    # 'rent_period':[-49.5],
    # 'rent_max_amt':[1325.0]

}


# XGB等算法配置
bin_params_dict_xgb = {
    'xgb_predicts': [0.5],
    'knn_predicts': [0.5],
    'dnn_predictions': [ 0.018, 0.034, 0.046, 0.073, 0.123, 0.175, 0.258],
    'bayes_predicts': [0.5],
     'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'ke_quality': [ 174.5, 312.5, 329.5, 361.5, 376.5, 403.5],
    # 'byj_loan_amount': [ 800, 1450.0, 29750.0],
    'byj_app_amount': [ 1450.0, 29750.0],
    'byj_loan_periods': [ 6, 9.0],
    # 'byj_loan_rate': [ -49.45],
    'income': [ 248554.5, 552007.5, 1133606.5, 1347582.0],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'agent_del_rate': [ -49.388, 0.384],
    # 'shop_del_rate': [ -49.048, 0.982],
    # 'agent_cnt': [ -6.5, 190.5],
    # 'agent_del_cnt': [ -39.5, 77.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'shop_del_cnt': [ -47.5],
    # 'shop_cnt':[ -47.5],
    'shop_annual_income':[ 3389728.5, 11353908.0, 18822910.0],
    # 'position_title_level':[1.5, 2.5, 3.5],
    'sex_male':[ 0.5],
    # 'degree_level':[-48.0, 2,5.0],#参数为负
    # 'census_city_level':[-49.0, 2.5, 4.5],
    # 'age':[ 25.5, 36.5],
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    # 'work_city_level':[3.5],#参数为负
    # 'census_type_level':[1.5, 2.5],#参数为负
    # 'list_ct':[-49.0, 1.5],
    # 'list_total_loan':[-49.5],#参数为负
    # 'list_total_mortgage':[-49.5],
    # 'house_ct':[-49.0],#参数为负
    # 'marriage_level':[1.5],#参数为负
    # 'college_level':[-49.0,3.5],#参数为负
    # 'rent_avg_amt':[1325.0],#参数为负
    # 'rent_period':[-49.5],
    # 'rent_max_amt':[1325.0]
}

#经纪人离职模型
bin_params_dict_jingjiren = {
    'inserve_days' : [ 52.5, 96.5, 1200.5],#作用太强
    'xgb_predicts' : [ 0.5],
    'income' : [ 11502.0, 38264.5, 64459.0, 97304.5, 147077.5, 303233.5, 587078.0],
    'position_title_level' : [ 1.5, 2.5, 3.5],
    'job_level' : [ 1.5, 2.5, 6.5],
    'ke_quality' : [ 200, 267.5, 283.5, 303.5, 330.5, 349.5],
    'age' : [ 22.5,  24.5, 26.5, 28.5,39.5],
    'avg_showing_month_ct' : [ -49.0, 3.5, 6.5],
    'dnn_predictions' : [ -0.407, -0.251, -0.018, 0.11, 0.734],#参数为负
    'census_city_level' : [ -49.0, 2.5, 3.5, 4.5],#参数为负
    'shop_annual_income' : [ 3081103.0, 7547785.0,  13543025.5],#参数为负
    'bayes_predicts' : [ 0.5],
    'shop_del_rate' : [ 0.077],#参数为负
    'shop_del_cnt' : [ -49.5, 7.5, 11.5],
    'if_bad' : [ -49.5, 0.5],
    # 'degree_level' : [ -48.0, 5.0, 7.0, 9.0],#WOE不单调
    'college_level' : [ -49.0, 2.5, 4.5, 5.5],
    'house_ct' : [ -49.0],
    # 'work_city_level' : [  4.5],#参数为负
    # 'byj_app_amount' : [ 1300.0],#参数为负
    # 'list_total_price' : [ 105000.0],#参数为负
    # 'list_avg_price' : [ 105000.0],#参数为负
    # 'marriage_level' : [ -49.0, 1.5],#参数为负
    # 'list_ct' : [ -49.0, 1.5],#参数为负
    'byj_loan_periods' : [ -49.0],

}

#经纪人离职模型 201912-30天
bin_params_dict_201912_30 = {
    'income': [ 32546.0, 62438.0, 98425.0, 150152.5, 283333.0, 473320.5, 803155.5],
    'ke_quality': [ 294.5, 308.5, 331.5, 337.5, 367.5, 391.5],
    # 'position_title_level': [ 1.5, 2.5, ],
    'inserve_days': [  191.5, 410.0, 842.5, 1247.5, 1680.5],
    'xgb_predicts': [ 0.5],
    # 'job_level': [ 1.5, 2.5, 6.5],
    'age': [ 22.5, 23.5, 24.5, 25.5, 27.5, 29.5, 41.5],
    'shop_annual_income': [  1818472.0, 3976573.5, 7626522.5, 12065750.5, ],
    # 'avg_showing_month_ct': [ 6.5, 7.5, 9.5, 16.5, 20.5],
    'degree_level': [ 5.0, 9.0, 13.0],
    # 'work_city_level': [4.5],
    'census_city_level': [ -49.0, 2.5, 3.5, 4.5],
    # 'marriage_level': [ 1.5],
    'byj_loan_amount': [ 200.5, 4050.0, 11350.0, 13650.0, 59750.0],
    # 'house_ct': [ -49.0, 1.5],
    # 'list_total_price': [ 354500.0, 498500.0, 632500.0, 719000.0, 1125000.0],
    # 'list_avg_price': [ 1450.5, 350500.0, 498500.0, 632073.156, 719000.0, 2922500.0],
    'rent_avg_amt': [ 1990.0, 2008.333, 2990.0, 3425.0, 4094.977, 4450.0, 6550.0],

}

#经纪人离职模型 201911-60天
bin_params_dict_201911_60 = {
    'income': [26850.5, 65650.0, 96404.5, 161520.0, 347453.0, 475588.0, 853248.0,],
    'ke_quality': [272.5, 292.5, 305.5, 317.5, 340.5, 366.5, 389.5,],
    'xgb_predicts': [0.5,],
    'position_title_level': [1.5, 2.5, 3.5, 4.5,],
    # 'inserve_days': [162.5, 216.5, 380.5, 895.5, 1219.5, 1942.5,],
    # 'job_level': [1.5, 2.5, 5.5,],
    'age': [22.5, 23.5, 24.5, 25.5, 26.5, 28.5, 38.5,],
    # 'avg_showing_month_ct': [ 5.5, 6.5, 7.5, 9.5, 11.5, 17.5,],
    'shop_annual_income': [1857197.0, 4249631.5, 5291226.5, 7157825.5, 9711657.5, 11664640.0, 13375328.0,],
    'census_city_level': [2.5, 3.5, 4.5,],
    'work_city_level': [4.5,],
    # 'marriage_level': [-49.0, 1.5,],
    'house_ct': [-49.0, 7.5,],
    # 'list_total_mortgage': [-49.5, 226.0, 205000.0,],
    'shop_del_rate': [0.062, 0.455, 0.947, 0.977, 0.993,],

}

# 经纪人离职模型 201910-90天
bin_params_dict = {
    'income': [29883.5, 68600.0, 106654.5, 176454.0, 338438.5, 476850.5, 808645.0,],
    'ke_quality': [265.5, 282.5, 303.5, 309.5, 320.5, 349.5, 381.5,],
    'xgb_predicts': [0.5,],
    # 'position_title_level': [1.5, 2.5, 3.5, 4.5,],
    # 'inserve_days': [113.5, 132.5, 192.5, 350.5, 504.5, 933.5, 1660.5,],
    'job_level': [1.5, 2.5, 6.5,],
    'age': [22.5, 23.5, 24.5, 25.5, 26.5, 28.5, 38.5,],
    'avg_showing_month_ct': [3.5, 4.5, 6.5, 7.5, 9.5, 11.5, 16.5,],
    'shop_annual_income': [1799226.5, 5553280.5, 6640166.0, 8337430.5, 10741851.5, 11400445.5, 14530798.0,],
    'census_city_level': [2.5, 3.5, 4.5,],
    'work_city_level': [3.5, 4.5,],
    'marriage_level': [-49.0, 1.5,],
    'house_ct': [-49.0, ],
    'shop_del_rate': [0.077, 0.476, 0.975, 0.985, 0.996,],

}

==> lapras-0.0.9.tar.gz: lapras-0.0.9/lapras/ModelConfig.py <==
# coding:utf-8

# 离散桶
bucketnum = 0
# 树深度
treeDepth = 3
# 最小子数目
minLeaf = 50

# 模型基准分
A = 363.7244
B = 57.7078
eps = 1e-8




# 房天下配置
bin_params_dict_fang = {
    'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'position_title_level':[1.5, 2.5, 3.5],
    # 'sex_male':[ 0.5], #数据异常
    # 'age':[ 25.5, 36.5], #数据异常
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    'work_city_level':[3.5],
    # 'census_type_level':[1.5, 2.5],#数据异常
    'list_ct':[-49.0, 1.5],
    # 'list_total_loan':[-49.5],#数据异常
    'house_ct':[-49.0],
    'marriage_level':[1.5],
    'rent_avg_amt':[1325.0],
    'rent_period':[-49.5],
}



#链家德佑KA的模型参数
bin_params_dict_lianjia = {
    'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'ke_quality': [ 174.5, 312.5, 329.5, 361.5, 376.5, 403.5],
    # 'byj_loan_amount': [ 800, 1450.0, 29750.0],
    'byj_app_amount': [ 1450.0, 29750.0],
    'byj_loan_periods': [ 6, 9.0],
    # 'byj_loan_rate': [ -49.45],
    'income': [ 248554.5, 552007.5, 1133606.5, 1347582.0],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'agent_del_rate': [ -49.388, 0.384],
    # 'shop_del_rate': [ -49.048, 0.982],
    # 'agent_cnt': [ -6.5, 190.5],
    # 'agent_del_cnt': [ -39.5, 77.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'shop_del_cnt': [ -47.5],
    # 'shop_cnt':[ -47.5],
    'shop_annual_income':[ 3389728.5, 11353908.0, 18822910.0],
    # 'position_title_level':[1.5, 2.5, 3.5],
    'sex_male':[ 0.5],
    'degree_level':[-48.0, 2,5.0],
    'census_city_level':[-49.0, 2.5, 4.5],
    'age':[ 25.5, 36.5],
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    'work_city_level':[3.5],
    'census_type_level':[1.5, 2.5],
    # 'list_ct':[-49.0, 1.5],
    'list_total_loan':[-49.5],
    # 'list_total_mortgage':[-49.5],
    'house_ct':[-49.0],
    'marriage_level':[1.5],
    'college_level':[-49.0,3.5],
    'rent_avg_amt':[1325.0],
    # 'rent_period':[-49.5],
    # 'rent_max_amt':[1325.0]

}


# XGB等算法配置
bin_params_dict_xgb = {
    'xgb_predicts': [0.5],
    'knn_predicts': [0.5],
    'dnn_predictions': [ 0.018, 0.034, 0.046, 0.073, 0.123, 0.175, 0.258],
    'bayes_predicts': [0.5],
     'avg_showing_month_ct': [ -49.0, 3.5, 4.5, 5.5, 6.5, 10.5],
    'ke_quality': [ 174.5, 312.5, 329.5, 361.5, 376.5, 403.5],
    # 'byj_loan_amount': [ 800, 1450.0, 29750.0],
    'byj_app_amount': [ 1450.0, 29750.0],
    'byj_loan_periods': [ 6, 9.0],
    # 'byj_loan_rate': [ -49.45],
    'income': [ 248554.5, 552007.5, 1133606.5, 1347582.0],
    'inserve_days': [ 79.5, 172.5, 352.5, 719.5, 931.5, 1075.5,1999.5,2999.5],
    'agent_del_rate': [ -49.388, 0.384],
    # 'shop_del_rate': [ -49.048, 0.982],
    # 'agent_cnt': [ -6.5, 190.5],
    # 'agent_del_cnt': [ -39.5, 77.5],
    'job_level':[1.5, 2.5, 3.5, 4.5, 5.5, 6.6],
    # 'shop_del_cnt': [ -47.5],
    # 'shop_cnt':[ -47.5],
    'shop_annual_income':[ 3389728.5, 11353908.0, 18822910.0],
    # 'position_title_level':[1.5, 2.5, 3.5],
    'sex_male':[ 0.5],
    # 'degree_level':[-48.0, 2,5.0],#参数为负
    # 'census_city_level':[-49.0, 2.5, 4.5],
    # 'age':[ 25.5, 36.5],
    'active_score':[ -49.5, 3.5, 11.5, 63.5],
    'list_total_price':[1326500.0, 4175000.0],
    'list_avg_price':[642500.0, 1323891.25],
    # 'work_city_level':[3.5],#参数为负
    # 'census_type_level':[1.5, 2.5],#参数为负
    # 'list_ct':[-49.0, 1.5],
    # 'list_total_loan':[-49.5],#参数为负
    # 'list_total_mortgage':[-49.5],
    # 'house_ct':[-49.0],#参数为负
    # 'marriage_level':[1.5],#参数为负
    # 'college_level':[-49.0,3.5],#参数为负
    # 'rent_avg_amt':[1325.0],#参数为负
    # 'rent_period':[-49.5],
    # 'rent_max_amt':[1325.0]
}

#经纪人离职模型
bin_params_dict_jingjiren = {
    'inserve_days' : [ 52.5, 96.5, 1200.5],#作用太强
    'xgb_predicts' : [ 0.5],
    'income' : [ 11502.0, 38264.5, 64459.0, 97304.5, 147077.5, 303233.5, 587078.0],
    'position_title_level' : [ 1.5, 2.5, 3.5],
    'job_level' : [ 1.5, 2.5, 6.5],
    'ke_quality' : [ 200, 267.5, 283.5, 303.5, 330.5, 349.5],
    'age' : [ 22.5,  24.5, 26.5, 28.5,39.5],
    'avg_showing_month_ct' : [ -49.0, 3.5, 6.5],
    'dnn_predictions' : [ -0.407, -0.251, -0.018, 0.11, 0.734],#参数为负
    'census_city_level' : [ -49.0, 2.5, 3.5, 4.5],#参数为负
    'shop_annual_income' : [ 3081103.0, 7547785.0,  13543025.5],#参数为负
    'bayes_predicts' : [ 0.5],
    'shop_del_rate' : [ 0.077],#参数为负
    'shop_del_cnt' : [ -49.5, 7.5, 11.5],
    'if_bad' : [ -49.5, 0.5],
    # 'degree_level' : [ -48.0, 5.0, 7.0, 9.0],#WOE不单调
    'college_level' : [ -49.0, 2.5, 4.5, 5.5],
    'house_ct' : [ -49.0],
    # 'work_city_level' : [  4.5],#参数为负
    # 'byj_app_amount' : [ 1300.0],#参数为负
    # 'list_total_price' : [ 105000.0],#参数为负
    # 'list_avg_price' : [ 105000.0],#参数为负
    # 'marriage_level' : [ -49.0, 1.5],#参数为负
    # 'list_ct' : [ -49.0, 1.5],#参数为负
    'byj_loan_periods' : [ -49.0],

}

#经纪人离职模型 201912-30天
bin_params_dict_201912_30 = {
    'income': [ 32546.0, 62438.0, 98425.0, 150152.5, 283333.0, 473320.5, 803155.5],
    'ke_quality': [ 294.5, 308.5, 331.5, 337.5, 367.5, 391.5],
    # 'position_title_level': [ 1.5, 2.5, ],
    'inserve_days': [  191.5, 410.0, 842.5, 1247.5, 1680.5],
    'xgb_predicts': [ 0.5],
    # 'job_level': [ 1.5, 2.5, 6.5],
    'age': [ 22.5, 23.5, 24.5, 25.5, 27.5, 29.5, 41.5],
    'shop_annual_income': [  1818472.0, 3976573.5, 7626522.5, 12065750.5, ],
    # 'avg_showing_month_ct': [ 6.5, 7.5, 9.5, 16.5, 20.5],
    'degree_level': [ 5.0, 9.0, 13.0],
    # 'work_city_level': [4.5],
    'census_city_level': [ -49.0, 2.5, 3.5, 4.5],
    # 'marriage_level': [ 1.5],
    'byj_loan_amount': [ 200.5, 4050.0, 11350.0, 13650.0, 59750.0],
    # 'house_ct': [ -49.0, 1.5],
    # 'list_total_price': [ 354500.0, 498500.0, 632500.0, 719000.0, 1125000.0],
    # 'list_avg_price': [ 1450.5, 350500.0, 498500.0, 632073.156, 719000.0, 2922500.0],
    'rent_avg_amt': [ 1990.0, 2008.333, 2990.0, 3425.0, 4094.977, 4450.0, 6550.0],

}

#经纪人离职模型 201911-60天
bin_params_dict_201911_60 = {
    'income': [26850.5, 65650.0, 96404.5, 161520.0, 347453.0, 475588.0, 853248.0,],
    'ke_quality': [272.5, 292.5, 305.5, 317.5, 340.5, 366.5, 389.5,],
    'xgb_predicts': [0.5,],
    'position_title_level': [1.5, 2.5, 3.5, 4.5,],
    # 'inserve_days': [162.5, 216.5, 380.5, 895.5, 1219.5, 1942.5,],
    # 'job_level': [1.5, 2.5, 5.5,],
    'age': [22.5, 23.5, 24.5, 25.5, 26.5, 28.5, 38.5,],
    # 'avg_showing_month_ct': [ 5.5, 6.5, 7.5, 9.5, 11.5, 17.5,],
    'shop_annual_income': [1857197.0, 4249631.5, 5291226.5, 7157825.5, 9711657.5, 11664640.0, 13375328.0,],
    'census_city_level': [2.5, 3.5, 4.5,],
    'work_city_level': [4.5,],
    # 'marriage_level': [-49.0, 1.5,],
    'house_ct': [-49.0, 7.5,],
    # 'list_total_mortgage': [-49.5, 226.0, 205000.0,],
    'shop_del_rate': [0.062, 0.455, 0.947, 0.977, 0.993,],

}

# 经纪人离职模型 201910-90天
bin_params_dict_aa = {
    'income': [29883.5, 68600.0, 106654.5, 176454.0, 338438.5, 476850.5, 808645.0,],
    'ke_quality': [265.5, 282.5, 303.5, 309.5, 320.5, 349.5, 381.5,],
    'xgb_predicts': [0.5,],
    # 'position_title_level': [1.5, 2.5, 3.5, 4.5,],
    # 'inserve_days': [113.5, 132.5, 192.5, 350.5, 504.5, 933.5, 1660.5,],
    'job_level': [1.5, 2.5, 6.5,],
    'age': [22.5, 23.5, 24.5, 25.5, 26.5, 28.5, 38.5,],
    'avg_showing_month_ct': [3.5, 4.5, 6.5, 7.5, 9.5, 11.5, 16.5,],
    'shop_annual_income': [1799226.5, 5553280.5, 6640166.0, 8337430.5, 10741851.5, 11400445.5, 14530798.0,],
    'census_city_level': [2.5, 3.5, 4.5,],
    'work_city_level': [3.5, 4.5,],
    'marriage_level': [-49.0, 1.5,],
    'house_ct': [-49.0, ],
    'shop_del_rate': [0.077, 0.476, 0.975, 0.985, 0.996,],

}

bin_params_dict = {'feature5': [157.105, 199.95, 244.5, 385.82],
 'feature7': [38.28, 43.725, 49.78, 52.005, 65.45, 70.065, 78.14],
 'feature16': [44.8, 100.25, 161.71, 249.26, 321.785],
 'feature3': [1.89, 2.485, 4.865, 19.105],
 'feature18': [6.5, 49.5, 116.0, 218.0, 553.5, 834.0],
 'feature2': [25.0, 204.0, 394.0, 500.5, 1145.504, 2686.45],
 'feature10': [1.89, 3.365, 5.17, 21.01],
 'feature14': [465.0, 550.0, 1000.5, 1993.6, 4040.0],
 'feature11': [0.165, 3.23, 3.915, 4.655, 7.22],
 'feature12': [7.5, 104.0, 320.0, 949.0, 5538.3],
 'feature8': [1.0, 32.0, 82.65, 110.835],
 'feature13': [2.5, 46.5, 675.0, 1000.5],
 'feature6': [29.0, 47.375, 58.38, 65.955, 74.34],
 'feature9': [1.0, 32.0, 66.635, 99.645],
 'feature15': [87.5, 121.5, 297.0, 600.263],
 'feature17': [0.5, 3.5, 4.5, 8.5, 10.5, 13.5],
 'feature4': [1.5, 2.5, 5.5, 9.5],

}
